[![PyPi version](https://img.shields.io/pypi/v/SpiNNakerGraphFrontEnd.svg?style=flat)](https://pypi.org/project/SpiNNakerGraphFrontEnd/)
[![Python Build Status](https://github.com/SpiNNakerManchester/SpiNNakerGraphFrontEnd/workflows/Python%20Actions/badge.svg?branch=master)](https://github.com/SpiNNakerManchester/SpiNNakerGraphFrontEnd/actions?query=workflow%3A%22Python+Actions%22+branch%3Amaster)
[![C Build Status](https://github.com/SpiNNakerManchester/SpiNNakerGraphFrontEnd/workflows/C%20Actions/badge.svg?branch=master)](https://github.com/SpiNNakerManchester/SpiNNakerGraphFrontEnd/actions?query=workflow%3A%22C+Actions%22+branch%3Amaster)
[![Documentation Status](https://readthedocs.org/projects/spinnakergraphfrontend/badge/?version=7.4.1)](https://spinnakergraphfrontend.readthedocs.io/en/7.4.1)
[![Coverage Status](https://coveralls.io/repos/github/SpiNNakerManchester/SpiNNakerGraphFrontEnd/badge.svg?branch=master)](https://coveralls.io/github/SpiNNakerManchester/SpiNNakerGraphFrontEnd?branch=master)

# SpiNNakerGraphFrontEnd
An front-end interface for running non-neural applications on SpiNNaker hardware.

Documentation
=============
[SpiNNakerGraphFrontEnd Python documentation](http://spinnakergraphfrontend.readthedocs.io/en/7.4.1)
<br>
[Combined python documentation](http://spinnakermanchester.readthedocs.io/en/7.4.1)

